@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2018 */
+/* Copyright (c) Philip Hazel, 2020 */
+/* Last modified August 2020 */
 
 /* This module contains functions related to fonts. */
 
@@ -150,8 +151,16 @@ uschar line[256];
 
 if (af->widths != NULL) return;    /* We have seen this afont before */
 
+/* First search for "fontmetrics/name" in the shared files directories; if not
+found, try just "name". */
+
 sprintf(CS line, "fontmetrics/%s.afm", af->name);
-(void)misc_find_share(line, filename, TRUE);
+if (!misc_find_share(line, filename, FALSE))
+  {
+  sprintf(CS line, "%s.afm", af->name);
+  (void)misc_find_share(line, filename, TRUE);  /* Hard error on failure */
+  }
+
 f = Ufopen(filename, "rb");
 if (f == NULL)
   (void)error(0, filename, "font metric file", strerror(errno));   /* Hard */
@@ -417,10 +426,12 @@ afontstr *af = vf->afont;
 
 if (chtype != NULL) *chtype = CHTYPE_STD;
 
-/* The zero-width space and the break-permitting chars do not appear in any
-font. */
+/* The zero-width space does not appear in any font, and the break-permitting
+characters do not appear in any standardly encoded font. */
 
-if (c == ZERO_SPACE || c == BREAK_PERMIT || c == NO_BREAK_HERE) return 0;
+if (c == ZERO_SPACE ||
+     (af->stdencoding && (c == BREAK_PERMIT || c == NO_BREAK_HERE)))
+  return 0;
 
 /* The "hard space" character, U+00A0, does not appear in the AFM files for the
 standard fonts. It is printed as a space, of course. */
