@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2018 */
+/* Copyright (c) Philip Hazel, 2020 */
+/* Last modified: August 2020 */
 
 /* This module contains code for handling graphics objects. */
 
@@ -192,8 +193,11 @@ else
   if (slash == NULL)
     (void)sprintf(CS buffer, "./%s", pfile->value);
   else
-    (void)sprintf(CS buffer, "%.*s/%s", (int)(slash - read_filename),
-      read_filename, pfile->value);
+    {
+    int blen = (int)(slash - read_filename);
+    memcpy(buffer, read_filename, blen);
+    (void)sprintf(CS buffer + blen, "/%s", pfile->value);
+    }
   }
 
 pform = misc_param_find(j, US"format");
