@@ -2,7 +2,8 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009, 2011, 2012, 2013 */
+/* Copyright (c) Philip Hazel, 2020 */
+/* Last modified: August 2020 */
 
 /* This module contains functions for doing things to paragraphs. */
 
@@ -1590,7 +1591,7 @@ for (;;)
       lhp_spacewidth = spacewidth;
       lhp_spacecount = spacecount;
       }
-    if (c == SOFT_HYPHEN) w = k = 0 ;       /* Adds no width when no split */
+    if (stdencoding && c == SOFT_HYPHEN) w = k = 0 ; /* No width for no split */
     }
 
   /* For both the filling and non-filling cases, add this character's kerned
